summaryrefslogtreecommitdiffstats
path: root/korganizer/plugins/projectview/koprojectview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/plugins/projectview/koprojectview.cpp')
-rw-r--r--korganizer/plugins/projectview/koprojectview.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/korganizer/plugins/projectview/koprojectview.cpp b/korganizer/plugins/projectview/koprojectview.cpp
index d5abb1f4..d0d2db38 100644
--- a/korganizer/plugins/projectview/koprojectview.cpp
+++ b/korganizer/plugins/projectview/koprojectview.cpp
@@ -45,11 +45,11 @@
using namespace KOrg;
-KOProjectViewItem::KOProjectViewItem(Todo *event,KGanttItem* parentTask,
+KOProjectViewItem::KOProjectViewItem(Todo *event,KGanttItem* tqparentTask,
const TQString& text,
const TQDateTime& start,
const TQDateTime& end) :
- KGanttItem(parentTask,text,start,end)
+ KGanttItem(tqparentTask,text,start,end)
{
mEvent = event;
}
@@ -64,9 +64,9 @@ Todo *KOProjectViewItem::event()
}
-KOProjectView::KOProjectView(Calendar *calendar,TQWidget* parent,
+KOProjectView::KOProjectView(Calendar *calendar,TQWidget* tqparent,
const char* name) :
- KOrg::BaseView(calendar,parent,name)
+ KOrg::BaseView(calendar,tqparent,name)
{
TQBoxLayout *topLayout = new TQVBoxLayout(this);
@@ -183,7 +183,7 @@ void KOProjectView::updateView()
*/
// Put for each Event a KOProjectViewItem in the list view. Don't rely on a
// specific order of events. That means that we have to generate parent items
// recursively for proper hierarchical display of Todos.
mTodoMap.clear();
Todo::List::ConstIterator it;
@@ -202,7 +202,7 @@ TQMap<Todo *,KGanttItem *>::ConstIterator
if (relatedTodo) {
// kdDebug(5850) << " has Related" << endl;
TQMap<Todo *,KGanttItem *>::ConstIterator itemIterator;
- itemIterator = mTodoMap.find(relatedTodo);
+ itemIterator = mTodoMap.tqfind(relatedTodo);
if (itemIterator == mTodoMap.end()) {
// kdDebug(5850) << " related not yet in list" << endl;
itemIterator = insertTodoItem (relatedTodo);
@@ -216,7 +216,7 @@ TQMap<Todo *,KGanttItem *>::ConstIterator
}
}
-KGanttItem *KOProjectView::createTask(KGanttItem *parent,Todo *todo)
+KGanttItem *KOProjectView::createTask(KGanttItem *tqparent,Todo *todo)
{
TQDateTime startDt;
TQDateTime endDt;
@@ -237,7 +237,7 @@ KGanttItem *KOProjectView::createTask(KGanttItem *parent,Todo *todo)
endDt = todo->dtDue();
}
- KGanttItem *task = new KOProjectViewItem(todo,parent,todo->summary(),startDt,
+ KGanttItem *task = new KOProjectViewItem(todo,tqparent,todo->summary(),startDt,
endDt);
connect(task,TQT_SIGNAL(changed(KGanttItem*, KGanttItem::Change)),
TQT_SLOT(taskChanged(KGanttItem*,KGanttItem::Change)));
@@ -183,7 +183,7 @@ void KOProjectView::updateView()
*/
// Put for each Event a KOProjectViewItem in the list view. Don't rely on a
- // specific order of events. That means that we have to generate parent items
+ // specific order of events. That means that we have to generate tqparent items
// recursively for proper hierarchical display of Todos.
mTodoMap.clear();